# AqOrg

Estimate the thermodynamic properties and HKF parameters of aqueous organic molecules using second order group additivity methods.
This [Jupyter notebook demo](https://gitlab.com/worm1/worm-library/-/blob/master/4-Thermodynamic-Property-Estimation/Introduction-Aq-Organic-Estimator.ipynb) introduces the underlying concepts.

## Installation

Install `AqOrg` with pip:

```
$ pip install aqorg
```

## Usage

See this [Jupyter notebook demo](https://gitlab.com/worm1/worm-library/-/blob/master/4-Thermodynamic-Property-Estimation/Aq-Organics-Feature-Demo/Aqueous-Organic-Molecules.ipynb) for examples.